==> AppleMacRISC4PE-102.2.1.tar.gz: AppleMacRISC4PE-102.2.1/IOPlatformPlugins/PowerMac7_2_PlatformPlugin/PowerMac7_2_PIDCtrlLoop.h <==
/*
 * Copyright (c) 2003 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 2003 Apple Computer, Inc.  All rights reserved.
 *
 *
 */
//		$Log $
//
//

#ifndef _POWERMAC7_2_PIDCTRLLOOP_H
#define _POWERMAC7_2_PIDCTRLLOOP_H

#include "IOPlatformPIDCtrlLoop.h"

class PowerMac7_2_PIDCtrlLoop : public IOPlatformPIDCtrlLoop
{

	OSDeclareDefaultStructors(PowerMac7_2_PIDCtrlLoop)

protected:

public:

	virtual bool updateMetaState( void );
	virtual const OSNumber *calculateNewTarget( void ) const;
};

#endif	// _POWERMAC7_2_PIDCTRLLOOP_H

==> AppleMacRISC4PE-112.1.17.tar.gz: AppleMacRISC4PE-112.1.17/IOPlatformPlugins/PowerMac7_2_PlatformPlugin/PowerMac7_2_PIDCtrlLoop.h <==
/*
 * Copyright (c) 2003-2004 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 2003-2004 Apple Computer, Inc.  All rights reserved.
 *
 *
 */


#ifndef _POWERMAC7_2_PIDCTRLLOOP_H
#define _POWERMAC7_2_PIDCTRLLOOP_H

#include "IOPlatformPIDCtrlLoop.h"

class PowerMac7_2_PIDCtrlLoop : public IOPlatformPIDCtrlLoop
{

	OSDeclareDefaultStructors(PowerMac7_2_PIDCtrlLoop)

protected:

public:

	virtual bool updateMetaState( void );
	virtual ControlValue calculateNewTarget( void ) const;
};

#endif	// _POWERMAC7_2_PIDCTRLLOOP_H
